#include <stdio.h>

/*
	Name:         modifylcp.c
	Description:  A small tool to modify the Little Computer People
	              data files on the Amiga.
	Author:       Matt Owen (aka Jaruzel)
	Email:        matt@jaruzel.com
	Date:         22nd July 2023
	Compilier:    Lattice C 5.0 Amiga
	Command Line: lc -L modifylcp.c
	Platform:     AmigaOS/Workbench 1.3
	
	Please excuse the simplistic C code presented here. I am not
	a C programmer, and this is my first C program for the Amiga.
	
	Also Lattice C is not C89 standard, but I wanted to restrict
	myself to the environemnt that LCP was released for.
*/

int havearg=0;
extern int errno;

void main(int argc, char *argv[]) {
  int keyi=0;
  havearg=argc;
      
  showmenu(); 
   
  while (keyi!=57) {
    errno=0;
	
    printf("\nSelect Option, and then press ENTER : ");
  
    keyi=getchar();
    printf("\n");

    /* printf("%d",keyi); */ 

    if (keyi==49) {
      newsn();
      modbrain(1,1,1);
      printf("NOTE: It may take a few minutes for your new LCP to move in.\n");
      printf("      Once he does, he will inspect the house for about\n");
      printf("      ten minutes. Only after that, can you talk to him.\n");
    }
        
    if (keyi==50) {
      modbrain(0,1,0);

    }
    if (keyi==51) {
      modbrain(0,0,1);
    }
    if (keyi==52) {
      showfile("LCP:LCPManual.txt");
      showmenu();
    }
    if (keyi==53) {
      showfile("LCP:Jaruzel.txt");
      showmenu();
    }
    
    if (keyi==57) {
      break;
    }
    
    /* Fetch and discard rogue keys - TODO: fix this! */
    keyi=getchar();

    /* printf("Done!\n"); */
  }
  
  exit(0);
}
int showmenu() {
  printf("%c",12);
  printf("\n\033[33mLittle Computer People Management Tool\033[0m\n");
  printf("by Matt Owen/Jaruzel (matt@jaruzel.com) July 2023 v1.0\n\n");
  printf(" 1. Evict Current LCP, and invite a new LCP to stay.\n");
  printf(" 2. Cure your sick LCP, so that he is healthy.\n");
  printf(" 3. Reset your LCPs personality.\n");
  printf(" 4. View the LCP Manual.\n");
  printf(" 5. About this management tool.\n\n");
  
  /* Use any old argument to change the text of option 9. */
  if(havearg==2){
   printf(" 9. Continue booting Little Computer People.\n");
  } else {
   printf(" 9. Exit LCP Mod tool.\n");
  }
 
 return 0;	
	
}

int newsn() {
  FILE *fh;
  char sn_new[] = "00000000NVTCA";
  char *sn_file="LCP:Misc/SN";
  char sn[13];
  char buff[10];
  long r;
  int i;
  
  fh=fopen(sn_file,"r");
  if(fh) {
    fscanf(fh,"%s",sn);
    fclose(fh);
  /*  printf("The current Serial Number is: %s\n",sn); */
  } else {
    printf("sn_file read error: %d\n",errno);
    exit(1);	
  }
  srand(time(NULL));
  r=rand();
  sprintf(buff,"%d",r);

  for (i=0;i<3;i++) {
    sn_new[i]=buff[i+6];
  }
 
  /* printf("The NEW Serial Number is:     %s\n",sn_new); */

  printf("\033[33m-> Inviting NEW LCP to stay...\033[0m\n"); 

  fh=fopen(sn_file,"w");
  if(fh) {
    fprintf(fh,"%s",sn_new);
    fclose
    (fh);
  } else {
    printf("sn_file write error: %d\n",errno);
    exit(1);
  }
  return 0;
}

int modbrain(int _evict, int _cure, int _lobot) {
  FILE *fh;
  char *brain_file="LCP:Misc/Brain";
  unsigned char brain[200];
  int i;
 
  fh=fopen(brain_file,"r");
  if(fh) {
    fread(brain,sizeof(brain),1,fh);
    fclose(fh);
  } else {
    printf("brain_file read error: %d\n",errno);
    exit(1);
  }
  if(_evict==1) {
    /* Resident LCP flag reset */
    printf("\033[33m-> Evicting current LCP...\033[0m\n");
    brain[0x43]=0x7A;
  }

  if(_cure==1) {
   /* Fix LCP health */
   printf("\033[33m-> Curing Any LCP Sickness..\033[0m\n");
   brain[0x27]=0xFE;
   brain[0x33]=0xFE;
   brain[0x2F]=0x14;
  }

  if(_lobot==1) {
    /* Reset LCP Personality back to Day 0 */
    printf("\033[33m-> Resetting LCP Personality...\033[0m\n");
    for(i=0x58;i<0xC8;i++) {
      brain[i]=0;

    }
  }
  
  fh=fopen(brain_file,"w");
  if(fh) {
    fwrite(brain,sizeof(brain),1,fh);
    fclose(fh);
  } else {
    printf("brain_file write error: %d\n",errno);
    exit(1);
  }

  return 0;
}

int showfile(char* text_file) {
  int lc=0;
  int maxlc=21;
  int keypress=0;
  char buffer[256];
  FILE *fh;
  
  keypress=getchar();
  
  printf("%c",12);
  
  fh=fopen(text_file,"r");
  if(fh) {
    while(fgets(buffer,256,fh)) {
	printf("%s",buffer);
	if(lc==maxlc) {
	  lc=0;
	  nextpage("for next page");
	} else {
          lc++;
        }
    }
    printf("\n");
  } else {
    printf("text_file read error: %d\n",errno);
    exit(1);
  }
  nextpage("to close");
  return 0;
	
}

int nextpage(char* msg) {
  int keypress=0;
  printf("\033[33mPress ENTER %s.\033[0m",msg);
  while(1) {
    keypress=getchar();
    if(keypress==10) {
      break;
    }
  }
  printf("\033[A\033[K\r");
  return 0;	
}
